Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3638)

Unified Diff: chrome/browser/ui/views/omnibox/omnibox_view_views.h

Issue 2341633006: MacViews/a11y: Allow accessibility clients to update the selected text. (Closed)
Patch Set: Rebase, fix OmniboxViewViews::AccessibilitySetValue. Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/ui/views/omnibox/omnibox_view_views.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/views/omnibox/omnibox_view_views.h
diff --git a/chrome/browser/ui/views/omnibox/omnibox_view_views.h b/chrome/browser/ui/views/omnibox/omnibox_view_views.h
index 2f45573895bc57c1b8bd62c20f7a5c57fcd8ad73..b861c558ace170b8b7f059e6e8118ea30bc8a071 100644
--- a/chrome/browser/ui/views/omnibox/omnibox_view_views.h
+++ b/chrome/browser/ui/views/omnibox/omnibox_view_views.h
@@ -127,8 +127,10 @@ class OmniboxViewViews
// Handles a request to change the value of this text field from software
// using an accessibility API (typically automation software, screen readers
- // don't normally use this). Sets the value and clears the selection.
- void AccessibilitySetValue(const base::string16& new_value);
+ // don't normally use this). Sets the value and clears the selection. If
+ // |replace| is true, insert at cursor or replace the selection.
+ void AccessibilitySetValue(const base::string16& new_value,
+ const bool replace);
tapted 2016/10/24 06:11:57 nit: remove const on |replace| (typically APIs don
Patti Lor 2016/10/25 04:25:19 Done.
// Updates |security_level_| based on the toolbar model's current value.
void UpdateSecurityLevel();
« no previous file with comments | « no previous file | chrome/browser/ui/views/omnibox/omnibox_view_views.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698